Module types

Module types 

A collection of standalone HID types that exist for type safety only. These are all simple wrappers around their underlying integer data type.

In this document and unless stated otherwise, a reference to “Section a.b.c” refers to the HID Device Class Definition for HID 1.11.

Structs

Delimiter
DesignatorIndex
DesignatorMaximum
DesignatorMinimum
LogicalMaximum
LogicalMinimum
PhysicalMaximum
PhysicalMinimum
ReportCount
ReportId
ReportSize
StringIndex
StringMaximum
StringMinimum
Unit
UnitExponent
UsageId
The 16-bit Usage Id identifier, see Section 5.5 “Usages”.
UsageMaximum
UsageMinimum
UsagePage
The 16-bit Usage Page identifier, see Section 5.5 “Usages”.

Enums

UnitSystem
Units