pub enum MainItem {
Input(InputItem),
Output(OutputItem),
Feature(FeatureItem),
Collection(CollectionItem),
EndCollection,
}Expand description
Main Items, see Section 6.2.2.4
Main items are used to either define or group certain types of data fields within a Report descriptor. There are two types of Main items: data and non-data. Data- type Main items are used to create a field within a report and include Input, Output, and Feature. Other items do not create fields and are subsequently referred to as non-data Main items.
Variants
Implementations